from okta.client import Client as OktaClient
import logging
import pytest


@pytest.mark.parametrize('log_level', [logging.INFO, logging.ERROR, logging.WARNING, logging.DEBUG])
def test_client_log_level_set_correctly(log_level: int):
    org_url = "https://test.okta.com"
    token = "TOKEN"
    config = {
        'orgUrl': org_url,
        'token': token,
        'logging': {
            'enabled': True,
            'logLevel': log_level
        }
    }

    # Ensure no error is raised and logger is set to correct level
    _ = OktaClient(user_config=config)
    assert logging.getLogger('okta-sdk-python').getEffectiveLevel() == log_level


def test_client_log_level_set_correctly_default():
    org_url = "https://test.okta.com"
    token = "TOKEN"
    config = {
        'orgUrl': org_url,
        'token': token,
        'logging': {
            'enabled': True
        }
    }

    # Ensure no error is raised and logger is set to correct level (INFO)
    _ = OktaClient(user_config=config)
    assert logging.getLogger('okta-sdk-python').getEffectiveLevel() == logging.INFO



from okta.jwt import JWT
import tests.mocks as mocks

"""
Testing JWT functions with different inputs
"""


def test_private_key_with_kid_in_private_key(mocker):
    mocked_encode = mocker.patch('jose.jwt.encode')
    JWT.create_token("test.com", "test-client-id", mocks.SAMPLE_JWK_WITH_KID)
    expected_kid = mocks.SAMPLE_JWK_WITH_KID["kid"]
    _, kwargs = mocked_encode.call_args
    mocked_encode.assert_called_once()
    assert "kid" in kwargs["headers"]
    assert kwargs["headers"]["kid"] == expected_kid


def test_private_key_with_kid_in_config(mocker):
    mocked_encode = mocker.patch('jose.jwt.encode')
    expected_kid = "test-kid"
    JWT.create_token("test.com", "test-client-id", mocks.SAMPLE_JWK, kid=expected_kid)
    _, kwargs = mocked_encode.call_args
    mocked_encode.assert_called_once()
    assert "kid" in kwargs["headers"]
    assert kwargs["headers"]["kid"] == expected_kid



# flake8: noqa
"""
Copyright 2020 - Present Okta, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

# AUTO-GENERATED! DO NOT EDIT FILE DIRECTLY
# SEE CONTRIBUTOR DOCUMENTATION

from okta.okta_object import OktaObject
from okta.okta_collection import OktaCollection


class GroupRuleGroupCondition(
    OktaObject
):
    """
    A class for GroupRuleGroupCondition objects.
    """

    def __init__(self, config=None):
        super().__init__(config)
        if config:
            self.exclude = OktaCollection.form_list(
                config["exclude"] if "exclude"\
                    in config else [],
                str
            )
            self.include = OktaCollection.form_list(
                config["include"] if "include"\
                    in config else [],
                str
            )
        else:
            self.exclude = []
            self.include = []

    def request_format(self):
        parent_req_format = super().request_format()
        current_obj_format = {
            "exclude": self.exclude,
            "include": self.include
        }
        parent_req_format.update(current_obj_format)
        return parent_req_format
